@@ -75,16 +75,16 @@ stringprep_locale_charset (void)
   if (charset && *charset)
     return charset;
 
-# ifdef LOCALE_WORKS
+#  ifdef LOCALE_WORKS
   charset = nl_langinfo (CODESET);
 
   if (charset && *charset)
     return charset;
-# endif
+#  endif
 
   return "ASCII";
 }
-#endif
+# endif
 
 /**
  * stringprep_convert:
@@ -114,11 +114,11 @@ stringprep_convert (const char *str,
 
   if (strcmp (to_codeset, from_codeset) == 0)
     {
-      char *p;
-      p = malloc (strlen (str) + 1);
-      if (!p)
+      char *q;
+      q = malloc (strlen (str) + 1);
+      if (!q)
 	return NULL;
-      return strcpy (p, str);
+      return strcpy (q, str);
     }
 
   cd = iconv_open (to_codeset, from_codeset);
